pub enum CloseSessionError {
InterfaceNotFound,
NotSupported,
// some variants omitted
}Expand description
Possible errors for closing the backing session.
Variants
InterfaceNotFound
The provided interface id is not found on the system.
NotSupported
The interface is not backed by a network-device or this operation is not supported by the netstack.
Implementations
Sourceimpl CloseSessionError
impl CloseSessionError
pub fn from_primitive(prim: u32) -> Option<CloseSessionError>
pub fn from_primitive_allow_unknown(prim: u32) -> CloseSessionError
pub fn unknown() -> CloseSessionError
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool