pub enum PacketCaptureEndReason {
InterfaceRemoved,
// some variants omitted
}Expand description
Reason for packet capture termination.
Variants
InterfaceRemoved
An interface that the capture is on was removed. Note that
this is never returned if the packet capture was started
with [InterfaceSpecifier.any]. When capturing on multiple interfaces,
the packet capture ends when any interface has been removed.
Implementations
Sourceimpl PacketCaptureEndReason
impl PacketCaptureEndReason
pub fn from_primitive(prim: u32) -> Option<PacketCaptureEndReason>
pub fn from_primitive_allow_unknown(prim: u32) -> PacketCaptureEndReason
pub fn unknown() -> PacketCaptureEndReason
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool