pub enum PacketCaptureReconnectError {
NotFound,
AlreadyConnected,
// some variants omitted
}Expand description
Errors returned when reconnecting to a rolling packet capture fails.
Variants
NotFound
No rolling packet capture with the provided name can be found.
AlreadyConnected
A channel attached or connected to this packet capture already exists.
Implementations
Sourceimpl PacketCaptureReconnectError
impl PacketCaptureReconnectError
pub fn from_primitive(prim: u32) -> Option<PacketCaptureReconnectError>
pub fn from_primitive_allow_unknown(prim: u32) -> PacketCaptureReconnectError
pub fn unknown() -> PacketCaptureReconnectError
pub const fn into_primitive(self) -> u32
pub fn is_unknown(&self) -> bool