pub struct CommonPacketCaptureParams {
pub interfaces: Option<InterfaceSpecifier>,
pub bpf_program: Option<VerifiedProgram>,
pub snap_len: Option<u32>,
/* private fields */
}Expand description
Parameters common to all packet capturing modes.
Fields
interfaces: Option<InterfaceSpecifier>Which interface(s) to capture on.
Required.
bpf_program: Option<VerifiedProgram>eBPF program for deciding which packets are included in the capture. The program must not make use of any eBPF-only features not present in cBPF. The program must be of type BPF_PROG_TYPE_SOCKET_FILTER and have been verified as such.
Optional.
snap_len: Option<u32>Number of bytes from the start of each packet to save in the capture. Truncation only happens at the end of the packet, no headers are skipped.
Optional, DEFAULT_SNAP_LEN is used if absent or 0 is passed.