InterfacesSynchronousProxy

Struct InterfacesSynchronousProxy 

pub struct InterfacesSynchronousProxy { /* private fields */ }

Implementations

Source

impl InterfacesSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<InterfacesEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn get_port( &self, id: u64, port: ServerEnd<PortMarker>, ) -> Result<(), Error>

Provides access to the port backing an interface.

port is closed with ZX_ERR_NOT_FOUND if an interface referenced by id does not exist or ZX_ERR_NOT_SUPPORTED if it is not backed by a [fuchsia.hardware.network/Port].

  • request id identifies the interface whose port is granted.
  • request port grants access to the interface’s device port.
pub fn close_backing_session( &self, id: u64, ___deadline: MonotonicInstant, ) -> Result<InterfacesCloseBackingSessionResult, Error>

Closes the session with the network device that backs the interface.

This method will wait for the backing session to be closed, which will result in the removal of the interface(s) using that session from the netstack. This is different from the traditional interface removal with fuchsia.net.interfaces.admin.Control in the sense that the latter does not close the session.

  • request id identifies the interface.
  • error INTERFACE_NOT_FOUND if the given id is not found.
  • error NOT_SUPPORTED if the interface is not backed by a network-device or if the operation is not supported.