pub struct PacketCaptureProviderMarker;Trait Implementations
Sourceimpl Clone for PacketCaptureProviderMarker
impl Clone for PacketCaptureProviderMarker
Sourcefn clone(&self) -> PacketCaptureProviderMarker
fn clone(&self) -> PacketCaptureProviderMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PacketCaptureProviderMarker
impl Debug for PacketCaptureProviderMarker
Sourceimpl DiscoverableProtocolMarker for PacketCaptureProviderMarker
impl DiscoverableProtocolMarker for PacketCaptureProviderMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for PacketCaptureProviderMarker
impl Hash for PacketCaptureProviderMarker
Sourceimpl Ord for PacketCaptureProviderMarker
impl Ord for PacketCaptureProviderMarker
Sourcefn cmp(&self, other: &PacketCaptureProviderMarker) -> Ordering
fn cmp(&self, other: &PacketCaptureProviderMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for PacketCaptureProviderMarker
impl PartialOrd for PacketCaptureProviderMarker
Sourceimpl ProtocolMarker for PacketCaptureProviderMarker
impl ProtocolMarker for PacketCaptureProviderMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.net.debug.PacketCaptureProvider"
const DEBUG_NAME: &'static str = "fuchsia.net.debug.PacketCaptureProvider"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = PacketCaptureProviderProxy
type Proxy = PacketCaptureProviderProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = PacketCaptureProviderRequestStream
type RequestStream = PacketCaptureProviderRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = PacketCaptureProviderSynchronousProxy
type SynchronousProxy = PacketCaptureProviderSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for PacketCaptureProviderMarker
impl Eq for PacketCaptureProviderMarker
impl StructuralPartialEq for PacketCaptureProviderMarker