pub struct PacketCaptureProviderProxy { /* private fields */ }Implementations
Sourceimpl PacketCaptureProviderProxy
impl PacketCaptureProviderProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.net.debug/PacketCaptureProvider.
Sourcepub fn take_event_stream(&self) -> PacketCaptureProviderEventStream
pub fn take_event_stream(&self) -> PacketCaptureProviderEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn start_rolling(
&self,
common_params: CommonPacketCaptureParams,
params: &RollingPacketCaptureParams,
) -> QueryResponseFut<PacketCaptureProviderStartRollingResult, DefaultFuchsiaResourceDialect>
pub fn start_rolling( &self, common_params: CommonPacketCaptureParams, params: &RollingPacketCaptureParams, ) -> QueryResponseFut<PacketCaptureProviderStartRollingResult, DefaultFuchsiaResourceDialect>
Start a rolling packet capture.
Lifetime of the packet capture is tied to the pipelined channel unless
[RollingPacketCapture.Detach] has been called.
Error
All variants of PacketCaptureStartError may be returned by this
method.
Sourcepub fn reconnect_rolling(
&self,
name: &str,
) -> QueryResponseFut<PacketCaptureProviderReconnectRollingResult, DefaultFuchsiaResourceDialect>
pub fn reconnect_rolling( &self, name: &str, ) -> QueryResponseFut<PacketCaptureProviderReconnectRollingResult, DefaultFuchsiaResourceDialect>
Reconnects to a packet capture previously started with
[PacketCaptureProvider/StartRolling].
Note reconnecting does not reattach the lifetime of the packet capture to
channel.