pub struct PacketCaptureProviderReconnectRollingResponse {
pub channel: ClientEnd<RollingPacketCaptureMarker>,
}Fields
channel: ClientEnd<RollingPacketCaptureMarker>Trait Implementations
Sourceimpl Decode<PacketCaptureProviderReconnectRollingResponse, DefaultFuchsiaResourceDialect> for PacketCaptureProviderReconnectRollingResponse
impl Decode<PacketCaptureProviderReconnectRollingResponse, DefaultFuchsiaResourceDialect> for PacketCaptureProviderReconnectRollingResponse
Sourceimpl Encode<PacketCaptureProviderReconnectRollingResponse, DefaultFuchsiaResourceDialect> for &mut PacketCaptureProviderReconnectRollingResponse
impl Encode<PacketCaptureProviderReconnectRollingResponse, DefaultFuchsiaResourceDialect> for &mut PacketCaptureProviderReconnectRollingResponse
Sourceimpl<T0: Encode<Endpoint<ClientEnd<RollingPacketCaptureMarker>>, DefaultFuchsiaResourceDialect>> Encode<PacketCaptureProviderReconnectRollingResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<Endpoint<ClientEnd<RollingPacketCaptureMarker>>, DefaultFuchsiaResourceDialect>> Encode<PacketCaptureProviderReconnectRollingResponse, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl Ord for PacketCaptureProviderReconnectRollingResponse
impl Ord for PacketCaptureProviderReconnectRollingResponse
Sourcefn cmp(&self, other: &PacketCaptureProviderReconnectRollingResponse) -> Ordering
fn cmp(&self, other: &PacketCaptureProviderReconnectRollingResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PacketCaptureProviderReconnectRollingResponse
impl PartialEq for PacketCaptureProviderReconnectRollingResponse
Sourcefn eq(&self, other: &PacketCaptureProviderReconnectRollingResponse) -> bool
fn eq(&self, other: &PacketCaptureProviderReconnectRollingResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for PacketCaptureProviderReconnectRollingResponse
impl PartialOrd for PacketCaptureProviderReconnectRollingResponse
Sourceimpl ResourceTypeMarker for PacketCaptureProviderReconnectRollingResponse
impl ResourceTypeMarker for PacketCaptureProviderReconnectRollingResponse
Sourcetype Borrowed<'a> = &'a mut PacketCaptureProviderReconnectRollingResponse
type Borrowed<'a> = &'a mut PacketCaptureProviderReconnectRollingResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for PacketCaptureProviderReconnectRollingResponse
impl TypeMarker for PacketCaptureProviderReconnectRollingResponse
Sourcetype Owned = PacketCaptureProviderReconnectRollingResponse
type Owned = PacketCaptureProviderReconnectRollingResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Eq for PacketCaptureProviderReconnectRollingResponse
impl Standalone<DefaultFuchsiaResourceDialect> for PacketCaptureProviderReconnectRollingResponse
impl StructuralPartialEq for PacketCaptureProviderReconnectRollingResponse