PacketCaptureProviderSynchronousProxy

Struct PacketCaptureProviderSynchronousProxy 

pub struct PacketCaptureProviderSynchronousProxy { /* private fields */ }

Implementations

Source

impl PacketCaptureProviderSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<PacketCaptureProviderEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn start_rolling( &self, common_params: CommonPacketCaptureParams, params: &RollingPacketCaptureParams, ___deadline: MonotonicInstant, ) -> Result<PacketCaptureProviderStartRollingResult, Error>

Start a rolling packet capture.

Lifetime of the packet capture is tied to the pipelined channel unless [RollingPacketCapture.Detach] has been called.

Error

All variants of PacketCaptureStartError may be returned by this method.

pub fn reconnect_rolling( &self, name: &str, ___deadline: MonotonicInstant, ) -> Result<PacketCaptureProviderReconnectRollingResult, Error>

Reconnects to a packet capture previously started with [PacketCaptureProvider/StartRolling].

If another channel is already connected to the packet capture, it will be closed to make room for this connection.

Note reconnecting does not reattach the lifetime of the packet capture to channel.