pub struct RollingPacketCaptureMarker;Trait Implementations
Sourceimpl Clone for RollingPacketCaptureMarker
impl Clone for RollingPacketCaptureMarker
Sourcefn clone(&self) -> RollingPacketCaptureMarker
fn clone(&self) -> RollingPacketCaptureMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RollingPacketCaptureMarker
impl Debug for RollingPacketCaptureMarker
Sourceimpl Hash for RollingPacketCaptureMarker
impl Hash for RollingPacketCaptureMarker
Sourceimpl Ord for RollingPacketCaptureMarker
impl Ord for RollingPacketCaptureMarker
Sourcefn cmp(&self, other: &RollingPacketCaptureMarker) -> Ordering
fn cmp(&self, other: &RollingPacketCaptureMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for RollingPacketCaptureMarker
impl PartialOrd for RollingPacketCaptureMarker
Sourceimpl ProtocolMarker for RollingPacketCaptureMarker
impl ProtocolMarker for RollingPacketCaptureMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) RollingPacketCapture"
const DEBUG_NAME: &'static str = "(anonymous) RollingPacketCapture"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = RollingPacketCaptureProxy
type Proxy = RollingPacketCaptureProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = RollingPacketCaptureRequestStream
type RequestStream = RollingPacketCaptureRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = RollingPacketCaptureSynchronousProxy
type SynchronousProxy = RollingPacketCaptureSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for RollingPacketCaptureMarker
impl Eq for RollingPacketCaptureMarker
impl StructuralPartialEq for RollingPacketCaptureMarker