pub struct RollingPacketCaptureSynchronousProxy { /* private fields */ }Implementations
Sourceimpl RollingPacketCaptureSynchronousProxy
impl RollingPacketCaptureSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<RollingPacketCaptureEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<RollingPacketCaptureEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn detach(
&self,
name: &str,
___deadline: MonotonicInstant,
) -> Result<RollingPacketCaptureDetachResult, Error>
pub fn detach( &self, name: &str, ___deadline: MonotonicInstant, ) -> Result<RollingPacketCaptureDetachResult, Error>
Detaches the lifetime of this protocol from the underlying packet capture.
After calling Detach, closing the client end no longer results in
the packet capture from being terminated. The passed string names
this packet capture and can be used thereafter to reconnect via
[PacketCaptureProvider.ReconnectRolling]. The protocol is still
detached after reconnecting. This gives the client the option of
ensuring the packet capture is resilient against disconnections.
Only the first call to Detach over the lifetime of the packet
capture (note this is different from the lifetime of this protocol
since it’s possible to disconnect and reconnect) is valid. Subsequent
calls cannot change the name of this capture.
Once this method returns, it is guaranteed that this rolling packet capture is detached.
Sourcepub fn stop_and_download(
&self,
channel: ServerEnd<FileMarker>,
) -> Result<(), Error>
pub fn stop_and_download( &self, channel: ServerEnd<FileMarker>, ) -> Result<(), Error>
Stop and make this rolling packet capture downloadable.
It is implicit by calling this method that the packet capture is stopped
due to user request, so the [RollingPacketCapture.OnEnded] event is
not emitted.
This method can be called multiple times, including across disconnects: a client can call this method, disconnect, reconnect, and call this method again.
The server discards the contents of the packet capture once this method has been called and there is no client connected to this protocol for some time.
Sourcepub fn discard(&self, ___deadline: MonotonicInstant) -> Result<(), Error>
pub fn discard(&self, ___deadline: MonotonicInstant) -> Result<(), Error>
Discard this rolling packet capture.
Clients should call this method when they have successfully downloaded the packet capture, or if they no longer need it for any reason.
The server closes all readers initialized via [StopAndDownload]
and all future interactions on this protocol are invalid. When this
method returns, it is guaranteed that the packet capture has been
discarded and the usage quota has been released.