pub enum InterfacesRequest {
GetPort {
id: u64,
port: ServerEnd<PortMarker>,
control_handle: InterfacesControlHandle,
},
CloseBackingSession {
id: u64,
responder: InterfacesCloseBackingSessionResponder,
},
}Expand description
Network interface debugging functionality.
This protocol is intended for debugging and testing only; and not meant for load-bearing code.
Variants
GetPort
Provides access to the port backing an interface.
port is closed with ZX_ERR_NOT_FOUND if an interface referenced by
id does not exist or ZX_ERR_NOT_SUPPORTED if it is not backed by a
[fuchsia.hardware.network/Port].
- request
ididentifies the interface whose port is granted. - request
portgrants access to the interface’s device port.
CloseBackingSession
Closes the session with the network device that backs the interface.
This method will wait for the backing session to be closed, which will
result in the removal of the interface(s) using that session from the
netstack. This is different from the traditional interface removal with
fuchsia.net.interfaces.admin.Control in the sense that the latter
does not close the session.
- request
ididentifies the interface.
- error
INTERFACE_NOT_FOUNDif the givenidis not found. - error
NOT_SUPPORTEDif the interface is not backed by a network-device or if the operation is not supported.
Implementations
Sourceimpl InterfacesRequest
impl InterfacesRequest
pub fn into_get_port( self, ) -> Option<(u64, ServerEnd<PortMarker>, InterfacesControlHandle)>
pub fn into_close_backing_session( self, ) -> Option<(u64, InterfacesCloseBackingSessionResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL