pub struct PacketCaptureProviderSynchronousProxy { /* private fields */ }Implementations
Sourceimpl PacketCaptureProviderSynchronousProxy
impl PacketCaptureProviderSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<PacketCaptureProviderEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<PacketCaptureProviderEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn start_rolling(
&self,
common_params: CommonPacketCaptureParams,
params: &RollingPacketCaptureParams,
___deadline: MonotonicInstant,
) -> Result<PacketCaptureProviderStartRollingResult, Error>
pub fn start_rolling( &self, common_params: CommonPacketCaptureParams, params: &RollingPacketCaptureParams, ___deadline: MonotonicInstant, ) -> Result<PacketCaptureProviderStartRollingResult, Error>
Start a rolling packet capture.
Lifetime of the packet capture is tied to the pipelined channel unless
[RollingPacketCapture.Detach] has been called.
Error
All variants of PacketCaptureStartError may be returned by this
method.
Sourcepub fn reconnect_rolling(
&self,
name: &str,
___deadline: MonotonicInstant,
) -> Result<PacketCaptureProviderReconnectRollingResult, Error>
pub fn reconnect_rolling( &self, name: &str, ___deadline: MonotonicInstant, ) -> Result<PacketCaptureProviderReconnectRollingResult, Error>
Reconnects to a packet capture previously started with
[PacketCaptureProvider/StartRolling].
Note reconnecting does not reattach the lifetime of the packet capture to
channel.