pub struct RollingPacketCaptureSynchronousProxy { /* private fields */ }Implementations
Sourceimpl RollingPacketCaptureSynchronousProxy
impl RollingPacketCaptureSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<RollingPacketCaptureEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<RollingPacketCaptureEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn detach(&self, name: &str) -> Result<(), Error>
pub fn detach(&self, name: &str) -> Result<(), Error>
Detaches the lifetime of this protocol from the underlying packet capture.
After calling Detach, closing the client end no longer results in
the packet capture from being terminated. The passed string names this
packet capture and can be used once to reconnect via
[PacketCaptureProvider.ReconnectRolling]. This gives the client the
option of ensuring the packet capture is resilient against
disconnections.
Detach can be called multiple times, but only the name passed in the
most recent call is valid and previously passed names are invalidated.
Sourcepub fn stop_and_download(
&self,
channel: ServerEnd<FileMarker>,
) -> Result<(), Error>
pub fn stop_and_download( &self, channel: ServerEnd<FileMarker>, ) -> Result<(), Error>
Stop and make this rolling packet capture downloadable.
It is implicit by calling this method that the packet capture is stopped
due to user request, so the [RollingPacketCapture.OnEnded] event is
not emitted.
This method can be called multiple times, including across disconnects: a client can call this method, disconnect, reconnect, and call this method again.
The server discards the contents of the packet capture once this method has been called and there is no client connected to this protocol for some time.
Sourcepub fn discard(&self) -> Result<(), Error>
pub fn discard(&self) -> Result<(), Error>
Discard this rolling packet capture.
Clients should call this method when they have successfully downloaded the packet capture, or if they no longer need it for any reason.
When this method is called, the server closes all readers initialized
via [StopAndDownload] and all future interactions on this protocol
are invalid.